@@ -35,6 +35,11 @@ SECRET_KEY = '-1evj*zt(60#q+u=-iy4sc7%f_a&tmrtox%salcf4a!^(49d^l'
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
+TEST_DIR_PATH = os.path.join(BASE_DIR, 'tests', 'boilerplate', "TestHtml")
+
+if not os.path.exists(TEST_DIR_PATH):
+    os.mkdir(TEST_DIR_PATH)
+
 DATABASES = {
     'default': {
         'NAME': 'Zephyrus.db',
@@ -86,7 +91,9 @@ if DEBUG:
     )
 else:
     STATIC_ROOT = os.path.join(BASE_DIR, 'tests', 'static')
-    
+
+if not os.path.exists(STATICFILES_DIRS[0]):
+    os.mkdir(STATICFILES_DIRS[0])    
     
 TEMPLATES = [
     {
@@ -107,6 +114,9 @@ TEMPLATES = [
     },
 ]
 
+if not os.path.exists(TEMPLATES[0]['DIRS'][0]):
+    os.mkdir(TEMPLATES[0]['DIRS'][0])    
+
 def getCMSTemplates():
     templates = []
     
