@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: pluginize.py 10257 2017-09-04 07:56:31Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-09-04 15:56:31 +0800 (週一, 04 九月 2017) $
+# $Revision: 10257 $
 
 import os
 import json
@@ -204,6 +204,11 @@ class Command(BaseCommand):
         def process():
             for file in os.listdir(path):
                 file = os.path.join(path, file)
+                
+                result = os.path.splitext(file)[-1]
+                if not result == ".html":
+                    continue
+                    
                 logger.info(file)
                 f = open(file)
                 t = template.Template(f.read())
