@@ -87,13 +87,16 @@ class BuildBoilerplateTest(unittest.TestCase):
         else:
             os.mkdir(STATIC_DIT_PATH)
 
-    def getTestStatic(self):
+    def getTestStatic(self, path):
         self.clearStaticDir()
-            
-        for dirName in os.listdir(TEST_STATIC_DIR_PATH):
-            dirPath = os.path.join(TEST_STATIC_DIR_PATH, dirName)
+        path = os.path.join(TEST_STATIC_DIR_PATH, path)
+        for dirName in os.listdir(path):
+            dirPath = os.path.join(path, dirName)
             dst = os.path.join(STATIC_DIT_PATH, dirName)
-            shutil.copytree(dirPath, dst)
+            if os.path.isdir(dirPath):
+                shutil.copytree(dirPath, dst)
+            else:
+                shutil.copyfile(dirPath, dst)
 
     def clearStaticDir(self):
         try:
@@ -102,15 +105,19 @@ class BuildBoilerplateTest(unittest.TestCase):
             logger.error("Static folder is not exist.")
         else:
             os.mkdir(STATIC_DIT_PATH)
-    
+
     def testComment(self):
         self.runBuildBoilerplate('Comment.html', 'CommentAnswer.html')
+
+    
+    def testDiv(self):
+        self.runBuildBoilerplate('Div.html', 'DivAnswer.html')
     
     def testSpecialWord(self):
         self.runBuildBoilerplate('SpecialWord.html', 'SpecialWordAnswer.html')
     
     def testStatic(self):
-        self.getTestStatic()
+        self.getTestStatic('TestStatic')
         self.runBuildBoilerplate('Static.html', 'StaticAnswer.html')
 
     # Z只是要讓這個函數最後跑
